package Bot::BasicBot::Pluggable::Module::Collection;

use strict;
use warnings;
our $VERSION = '0.01';

1;
__END__

=head1 NAME

Bot::BasicBot::Pluggable::Module::Collection - some useful IRC modules

=head1 SYNOPSIS

  use Bot::BasicBot::Pluggable::Module::Collection;

=head1 DESCRIPTION

Bot::BasicBot::Pluggable::Module::Collection is

=head1 AUTHOR

DannE<lt>techmemo {at} gmail.comE<gt>

=head1 SEE ALSO

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
